package com.qmth.ops.api.controller.admin;

import com.qmth.ops.api.binder.FileFormatBinder;
import com.qmth.ops.api.constants.OpsApiConstants;
import com.qmth.ops.biz.domain.ConfigGroup;
import com.qmth.ops.biz.domain.ConfigItem;
import com.qmth.ops.biz.domain.FileFormat;
import com.qmth.ops.biz.service.*;
import org.springframework.web.bind.WebDataBinder;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.annotation.Resource;
import java.io.IOException;
import java.util.List;

@RestController
@RequestMapping(OpsApiConstants.ADMIN_URI_PREFIX + "/config")
public class ConfigController {

    @Resource
    private ConfigGroupService configGroupService;

    @Resource
    private ConfigService configService;

    @Resource
    private AppService appService;

    @Resource
    private ModuleService moduleService;

    @Resource
    private VersionService versionService;

    @InitBinder
    public void initBinder(WebDataBinder dataBinder) {
        dataBinder.addCustomFormatter(new FileFormatBinder());
    }

    @PostMapping("/groups")
    public List<ConfigGroup> listGroups() {
        return configGroupService.getConfigGroupList();
    }

    @PostMapping("/baseline")
    public List<ConfigItem> listBaseline(@RequestParam Long appId, @RequestParam Long versionId,
            @RequestParam Long moduleId) {
        return configService.listBaseline(appId, versionId, moduleId);
    }

    @PostMapping("/baseline/update")
    public Object updateBaseline(@RequestParam Long appId, @RequestParam Long versionId, @RequestParam Long moduleId,
            @RequestParam MultipartFile file, @RequestParam FileFormat extension,
            @RequestParam(required = false) Long inheritVersionId) throws IOException {
        return configService.updateBaseline(appService.getById(appId), versionService.getById(versionId),
                moduleService.getById(moduleId), file.getInputStream(), extension,
                inheritVersionId != null ? versionService.getById(inheritVersionId) : null);
    }

    @PostMapping("/baseline/item/update")
    public ConfigItem updateBaselineItem(ConfigItem item) {
        return configService.updateBaselineItem(item);
    }

    @PostMapping("/list")
    public List<ConfigItem> listConfigItem(@RequestParam Long appId, @RequestParam Long versionId,
            @RequestParam Long moduleId, @RequestParam Long envId) {
        return configService.listConfigItem(appId, versionId, moduleId, envId);
    }

    @PostMapping("/item/update")
    public ConfigItem updateConfigItem(ConfigItem item) {
        return configService.updateConfigItem(item);
    }
}

