package com.qmth.ops.biz.service;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.qmth.ops.biz.dao.UserDao;
import com.qmth.ops.biz.domain.User;
import com.qmth.ops.biz.query.UserQuery;
import org.apache.commons.lang3.RandomStringUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;

@Service
public class UserService extends ServiceImpl<UserDao, User> {

    @Resource
    private UserDao userDao;

    public User findByLoginName(String loginName) {
        return userDao.selectOne(new LambdaQueryWrapper<User>().eq(User::getLoginName, loginName));
    }

    public User findByExportSecret(String exportSecret) {
        return userDao.selectOne(new LambdaQueryWrapper<User>().eq(User::getExportSecret, exportSecret));
    }

    @Transactional
    public User insert(User user) {
        user.setExportSecret(RandomStringUtils.random(32, true, true));
        user.setCreateTime(System.currentTimeMillis());
        user.setUpdateTime(user.getCreateTime());
        user.setPassword(user.buildPassword(user.getPassword()));
        userDao.insert(user);
        return user;
    }

    public UserQuery query(UserQuery query) {
        return userDao.selectPage(query, query.build());
    }
}
